@@ -33,16 +33,17 @@
  *
  * TODO:
  *
+ * - Use color selection dialog
  * - provide mechanism for configuring ARGB cursor themes, etc...
  */
 
 
-#include <stdio.h>  /* sprintf */
+
 #include <gtk/gtk.h>
 
 #include "NvCtrlAttributes.h"
 
-#include "cursor_banner.h"
+#include "ctkimage.h"
 
 #include "ctkcursorshadow.h"
 #include "ctkscale.h"
@@ -67,7 +68,7 @@ static const char *__alpha_help =
 "shadow is.";
 
 static const char *__color_selector_help =
-"The Cursor Shadow Color Selector button toggles "
+"The Cursor Shadow Color Selector checkbox toggles "
 "the Cursor Shadow Color Selector window, which allows "
 "you to select the color for the cursor shadow.";
 
@@ -145,8 +146,6 @@ static gboolean
 color_selector_window_destroy(GtkWidget *widget, GdkEvent *event,
                               gpointer user_data);
 
-static void post_color_selector_changed(CtkCursorShadow *ctk_cursor_shadow,
-                                        gint red, gint green, gint blue);
 
 static void color_selector_changed(GtkColorSelection *colorselection,
                                    gpointer user_data);
@@ -201,20 +200,15 @@ GtkWidget* ctk_cursor_shadow_new(NvCtrlAttributeHandle *handle,
 {
     GObject *object;
     CtkCursorShadow *ctk_cursor_shadow;
-    GtkWidget *image;
+    GtkWidget *banner;
     GtkWidget *frame;
     GtkWidget *alignment;
     GtkWidget *hbox;
     GtkWidget *vbox;
     GtkWidget *check_button;
     GtkWidget *label;
-    GdkColor   color;
     ReturnStatus ret;
     gint enabled;
-    guint8 *image_buffer = NULL;
-    const nv_image_t *img;
-    gint red, green, blue;
-    char str[16];
 
     /* check to see if we can support cursor shadow */
     
@@ -237,25 +231,8 @@ GtkWidget* ctk_cursor_shadow_new(NvCtrlAttributeHandle *handle,
 
     /* banner */
 
-    hbox = gtk_hbox_new(FALSE, 0);
-    gtk_box_pack_start(GTK_BOX(ctk_cursor_shadow), hbox, FALSE, FALSE, 0);
-
-    frame = gtk_frame_new(NULL);
-    gtk_box_pack_start(GTK_BOX(hbox), frame, FALSE, FALSE, 0);
-    
-    gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_IN);
-    
-    img = &cursor_banner_image;
-
-    image_buffer = decompress_image_data(img);
-
-    image = gtk_image_new_from_pixbuf
-        (gdk_pixbuf_new_from_data(image_buffer, GDK_COLORSPACE_RGB,
-                                  FALSE, 8, img->width, img->height,
-                                  img->width * img->bytes_per_pixel,
-                                  free_decompressed_image, NULL));
-
-    gtk_container_add(GTK_CONTAINER(frame), image);
+    banner = ctk_banner_image_new(BANNER_ARTWORK_CURSOR_SHADOW);
+    gtk_box_pack_start(GTK_BOX(ctk_cursor_shadow), banner, FALSE, FALSE, 0);
 
     /* vbox */
 
@@ -321,81 +298,25 @@ GtkWidget* ctk_cursor_shadow_new(NvCtrlAttributeHandle *handle,
                      (gpointer) ctk_cursor_shadow);
     
 
-    /* "Color Shadow Selector" button */
+    /* "Color Shadow Selector" check box */
     
-    ctk_cursor_shadow->color_selector_button =
-        gtk_toggle_button_new();
+    ctk_cursor_shadow->color_selector_check_button =
+        gtk_check_button_new_with_label("Cursor Shadow Color Selector");
 
-    /* Cursor Shadow Color Box */
-    
-    frame = gtk_aspect_frame_new(NULL, 0, 0, 1, FALSE);
-
-    gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_OUT);
-
-    gtk_container_set_border_width(GTK_CONTAINER(frame), 1);
-
-
-    ctk_cursor_shadow->cursor_shadow_bg = gtk_event_box_new();
-
-    gtk_widget_set_size_request(ctk_cursor_shadow->cursor_shadow_bg, 10, 10);
-
-    /* Grab current cursor shadow color */
-
-    NvCtrlGetAttribute(ctk_cursor_shadow->handle,
-                       NV_CTRL_CURSOR_SHADOW_RED, &red);
-    
-    NvCtrlGetAttribute(ctk_cursor_shadow->handle,
-                       NV_CTRL_CURSOR_SHADOW_GREEN, &green);
-    
-    NvCtrlGetAttribute(ctk_cursor_shadow->handle,
-                       NV_CTRL_CURSOR_SHADOW_BLUE, &blue);
-    
-    sprintf(str, "#%2.2X%2.2X%2.2X", red, green, blue);
-
-    gdk_color_parse (str, &color);
-
-    gtk_widget_modify_bg(ctk_cursor_shadow->cursor_shadow_bg,
-                         GTK_STATE_NORMAL, &color);
-
-    gtk_widget_modify_bg(ctk_cursor_shadow->cursor_shadow_bg,
-                         GTK_STATE_ACTIVE, &color);
-
-    gtk_widget_modify_bg(ctk_cursor_shadow->cursor_shadow_bg,
-                         GTK_STATE_PRELIGHT, &color);
-
-    /* pack cursor color selector button */
-
-    gtk_container_add(GTK_CONTAINER(frame),
-                      ctk_cursor_shadow->cursor_shadow_bg);
-    
-    label = gtk_label_new("Cursor Shadow Color Selector");
-
-    hbox  = gtk_hbox_new(FALSE, 0);
-
-    gtk_box_pack_start( GTK_BOX(hbox), frame, TRUE, TRUE, 2);
-
-    gtk_box_pack_end( GTK_BOX(hbox), label, FALSE, FALSE, 5);
-
-    gtk_container_add(GTK_CONTAINER(ctk_cursor_shadow->color_selector_button),
-                      hbox);
-
-    hbox = gtk_hbox_new(FALSE, 5);
-    gtk_box_pack_start(GTK_BOX(hbox),
-                       ctk_cursor_shadow->color_selector_button,
+    gtk_box_pack_start(GTK_BOX(vbox),
+                       ctk_cursor_shadow->color_selector_check_button,
                        FALSE, FALSE, 0);
-
-    gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 5);
-
+    
     gtk_toggle_button_set_active
-        (GTK_TOGGLE_BUTTON(ctk_cursor_shadow->color_selector_button),
+        (GTK_TOGGLE_BUTTON(ctk_cursor_shadow->color_selector_check_button),
          FALSE);
     
-    g_signal_connect(G_OBJECT(ctk_cursor_shadow->color_selector_button),
-                     "clicked", G_CALLBACK(color_toggled),
+    g_signal_connect(G_OBJECT(ctk_cursor_shadow->color_selector_check_button),
+                     "toggled", G_CALLBACK(color_toggled),
                      (gpointer) ctk_cursor_shadow);
     
     ctk_config_set_tooltip(ctk_config,
-                           ctk_cursor_shadow->color_selector_button,
+                           ctk_cursor_shadow->color_selector_check_button,
                            __color_selector_help);
    
     /* Color Selector */
@@ -656,9 +577,6 @@ static void reset_defaults(GtkButton *button, gpointer user_data)
 
     gtk_color_selection_set_current_color
         (GTK_COLOR_SELECTION(ctk_cursor_shadow->color_selector), &color);
-
-    post_color_selector_changed(ctk_cursor_shadow,
-                                color.red, color.green, color.blue);
     
     g_signal_handlers_unblock_matched
         (G_OBJECT(ctk_cursor_shadow->color_selector),
@@ -780,8 +698,6 @@ static void set_cursor_shadow_sensitivity(CtkCursorShadow *ctk_cursor_shadow,
     
     gtk_widget_set_sensitive(ctk_cursor_shadow->color_selector, enabled);
 
-    gtk_widget_set_sensitive(ctk_cursor_shadow->color_selector_button, enabled);
-
     /*
      * We separately track whether the reset button should be
      * sensitive because, unlike the sliders (which should be
@@ -867,13 +783,10 @@ static void init_color_selector(CtkCursorShadow *ctk_cursor_shadow)
     GtkWidget *window;
     GtkWidget *vbox;
     GtkWidget *hbox;
-    GtkWidget *frame;
-    GtkWidget *image;
+    GtkWidget *banner;
     GtkWidget *hseparator;
     GtkWidget *button;
     GtkWidget *alignment;
-    const nv_image_t *img;
-    guint8 *image_buffer = NULL;
     guint ret;
 
     /* create the color selector window */
@@ -884,7 +797,7 @@ static void init_color_selector(CtkCursorShadow *ctk_cursor_shadow)
 
     /* create a vbox to pack all the window contents in */
 
-    vbox = gtk_vbox_new(FALSE, 5);
+    vbox = gtk_vbox_new(FALSE, 10);
     gtk_container_add(GTK_CONTAINER(window), vbox);
     
     /* add a banner */
@@ -892,22 +805,8 @@ static void init_color_selector(CtkCursorShadow *ctk_cursor_shadow)
     hbox = gtk_hbox_new(FALSE, 0);
     gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 
-    frame = gtk_frame_new(NULL);
-    gtk_box_pack_start(GTK_BOX(hbox), frame, FALSE, FALSE, 0);
-
-    gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_IN);
-
-    img = &cursor_banner_image;
-
-    image_buffer = decompress_image_data(img);
-
-    image = gtk_image_new_from_pixbuf
-        (gdk_pixbuf_new_from_data(image_buffer, GDK_COLORSPACE_RGB,
-                                  FALSE, 8, img->width, img->height,
-                                  img->width * img->bytes_per_pixel,
-                                  free_decompressed_image, NULL));
-    
-    gtk_container_add(GTK_CONTAINER(frame), image);
+    banner = ctk_banner_image_new(BANNER_ARTWORK_CURSOR_SHADOW);
+    gtk_box_pack_start(GTK_BOX(hbox), banner, TRUE, TRUE, 0);
     
     /* create the color selector */
 
@@ -1028,7 +927,7 @@ color_selector_close_button_clicked(GtkButton *button, gpointer user_data)
     CtkCursorShadow *ctk_cursor_shadow = CTK_CURSOR_SHADOW(user_data);
     
     gtk_toggle_button_set_active
-        (GTK_TOGGLE_BUTTON(ctk_cursor_shadow->color_selector_button),
+        (GTK_TOGGLE_BUTTON(ctk_cursor_shadow->color_selector_check_button),
          FALSE);
     
 } /* color_selector_close_button_clicked() */
@@ -1042,7 +941,7 @@ color_selector_window_destroy(GtkWidget *widget, GdkEvent *event,
     CtkCursorShadow *ctk_cursor_shadow = CTK_CURSOR_SHADOW(user_data);
     
     gtk_toggle_button_set_active
-        (GTK_TOGGLE_BUTTON(ctk_cursor_shadow->color_selector_button),
+        (GTK_TOGGLE_BUTTON(ctk_cursor_shadow->color_selector_check_button),
          FALSE);
     
     return TRUE;
@@ -1098,23 +997,6 @@ static int get_value_and_range(CtkCursorShadow *ctk_cursor_shadow,
 static void post_color_selector_changed(CtkCursorShadow *ctk_cursor_shadow,
                                         gint red, gint green, gint blue)
 {
-    GdkColor color;
-    char     str[16];
-    sprintf(str, "#%2.2X%2.2X%2.2X", red, green, blue);
-
-
-    /* Update the color square */
-
-    gdk_color_parse(str, &color);
-    gtk_widget_modify_bg(ctk_cursor_shadow->cursor_shadow_bg,
-                         GTK_STATE_NORMAL, &color);
-
-    gtk_widget_modify_bg(ctk_cursor_shadow->cursor_shadow_bg,
-                         GTK_STATE_ACTIVE, &color);
-
-    gtk_widget_modify_bg(ctk_cursor_shadow->cursor_shadow_bg,
-                         GTK_STATE_PRELIGHT, &color);
-
     /* make the reset button sensitive */
     
     ctk_cursor_shadow->reset_button_sensitivity = TRUE;
